<li class="border-b flex-grow text-center md:border-b-0 md:border-r last:border-0 dark:border-base-700">
    <a href="{{ link }}" class="block px-4 py-2 text-left whitespace-nowrap hover:text-primary-600 dark:hover:text-primary-500"{% if blank %} target="_blank"{% endif %} {% include "unfold/helpers/attrs.html" with attrs=action.attrs %}>
        {{ title }}
    </a>
</li>
